# MBASIC Electronics Programs

Hardware interfacing and electronics tools

## Available Electronics

### 555-Ic

555 Timer calculator - calculates resistance and capacitance values for proper operation of the 555 timer-oscillator at desired frequency

**Year:** 1980s
**Tags:** timer, 555, oscillator, calculator

**[Download 555-ic.bas](555-ic.bas)**

---

### 567-Ic

567 Tone Decoder calculator - calculates resistance and capacitance values for proper operation of the 567 tone decoder IC

**Year:** 1980s
**Tags:** tone-decoder, 567, calculator

**[Download 567-ic.bas](567-ic.bas)**

---

### Atten

Attenuator design program - designs T, PI, or minimum loss attenuators for RF circuits (by Trevor Marshall, 1982)

**Author:** Trevor Marshall
**Year:** 1982
**Tags:** attenuator, rf, circuit-design

**[Download atten.bas](atten.bas)**

---

### Bc2

BASICODE 2 standard implementation - terminal emulation and compatibility layer for BASICODE programs (by Henk Wevers, 1983)

**Author:** Henk Wevers
**Year:** 1983
**Tags:** basicode, terminal, emulation

**[Download bc2.bas](bc2.bas)**

---

### Bearing

Compute bearings between geographic coordinates - calculates distance and bearing between two latitude/longitude positions (by Paul Macdonald, adapted by Jim Lill, 1987)

**Author:** Paul Macdonald, adapted by Jim Lill
**Year:** 1987
**Tags:** geography, navigation, coordinates, bearing

**[Download bearing.bas](bearing.bas)**

---

### Lst8085

8085 Assembly language lister - converts assembly language source to listing format for Intel 8085 processor

**Year:** 1980s
**Tags:** assembly, 8085, disassembler, intel

**[Download lst8085.bas](lst8085.bas)**

---

### Lstintel

Intel assembly language lister - converts assembly language source to listing format for Intel 8080 processor

**Year:** 1980s
**Tags:** assembly, 8080, disassembler, intel

**[Download lstintel.bas](lstintel.bas)**

---

### Lsttdl

TDL assembly language lister - converts assembly language source to listing format for TDL (Technical Design Labs) assembler

**Year:** 1980s
**Tags:** assembly, tdl, disassembler

**[Download lsttdl.bas](lsttdl.bas)**

---

### Tab8085

8085 opcode table generator - creates opcode reference tables for Intel 8085 assembly language programming

**Year:** 1980s
**Tags:** assembly, 8085, opcodes, reference

**[Download tab8085.bas](tab8085.bas)**

---

### Tabintel

Intel 8080 opcode table generator - creates opcode reference tables for Intel 8080 assembly language programming

**Year:** 1980s
**Tags:** assembly, 8080, opcodes, reference

**[Download tabintel.bas](tabintel.bas)**

---

### Tabtdl

TDL opcode table generator - creates opcode reference tables for TDL (Technical Design Labs) assembly language programming

**Year:** 1980s
**Tags:** assembly, tdl, opcodes, reference

**[Download tabtdl.bas](tabtdl.bas)**

---

### Tabzilog

Zilog Z80 opcode table generator - creates opcode reference tables for Zilog Z80 assembly language programming

**Year:** 1980s
**Tags:** assembly, z80, zilog, opcodes, reference

**[Download tabzilog.bas](tabzilog.bas)**

---

### Timer555

555 Timer circuit calculator - calculates component values for 555 timer circuits (similar to 555-ic.bas)

**Year:** 1980s
**Tags:** timer, 555, calculator, circuit

**[Download timer555.bas](timer555.bas)**

---

## How to Use

1. **Download** the .bas file you want to use
2. **Open MBASIC** in your preferred UI (Web, Tkinter, Curses, or CLI)
3. **Open the file:**
   - **Web/Tkinter UI:** Click File → Open, select the downloaded file
   - **CLI:** Type `LOAD "filename.bas"`
4. **Run:** Type `RUN` or press the Run button

## About These Electronics

These programs are from the CP/M and early PC era (1970s-1980s), 
preserved from historical archives including OAK, Simtel, and CP/M CD-ROMs.
